using System;
using System.Windows.Forms;
using System.Threading;     // Mutex

namespace HarborMist
{
    static class Program
    {



        // the main entry point for the application
        // STA means single thread apartment
        [STAThread]
        static void Main()
        {
            bool ownsMutex;
            Mutex myMutex = null;
            try
            {
                // Mutex constructor sets ownsMutex to false if mutex already exists,
                //    or to true if a new mutex was just created
                myMutex = new Mutex(false, Application.ProductName, out ownsMutex);
                if (!ownsMutex)
                {
                    MessageBox.Show
                        (
                           Application.ProductName + " is already running."
                        );
                    return; // do not allow this program to run twice
                }
                GC.KeepAlive(myMutex);

                Application.EnableVisualStyles();
                Application.Run(new Form1());
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message.ToString() +
                    "\r\n\r\nThis application will close.");
                foreach (Form frm in Application.OpenForms) frm.Close();
            }
            finally
            {
                // be sure and release Mutex before program exits
                if (myMutex != null) myMutex.Close();
                Application.Exit();
            }
        }


        // ------------------- public properties ----------------


        // shortened product version for display in menus or window titles
        public static string VersionShort
        {
            get
            {
                string stringMe = "Model.VersionShort: ";
                try
                {
                    string[] s = Application.ProductVersion.Split('.');
                    string myStr = s[0] + "." + s[1];
                    return myStr;
                }
                catch (Exception ex)
                { throw new Exception(stringMe + ex.Message); }
            }
            set { ; }
        }


    }
}